==> paraview-3.8.0.tbz: include/paraview-3.8/vtkPVConfig.h <==
/*=========================================================================

  Program:   ParaView
  Module:    vtkPVConfig.h.in

  Copyright (c) Kitware, Inc.
  All rights reserved.
  See Copyright.txt or http://www.paraview.org/HTML/Copyright.html for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/

#ifndef __vtkPVConfig_h
#define __vtkPVConfig_h

#define PARAVIEW_LINK_XDMF
/* #undef PARAVIEW_USE_ICE_T */
#define PARAVIEW_USE_SYSTEM_HDF5
/* #undef PARAVIEW_USE_SILO */
/* #undef XDMF_SYSTEM_HDF5 */
/* #undef PARAVIEW_BUILD_DEVELOPMENT */
/* #undef PARAVIEW_BLT_LIBRARY */
/* #undef PARAVIEW_ENABLE_PYTHON */
/* #undef PARAVIEW_MINIMAL_BUILD */

// Indicates the Qt support is enabled in VTK.
#define VTK_USE_QVTK

// Build ParaView with Floating Point Exceptions turned on
/* #undef PARAVIEW_ENABLE_FPE */
//Build ParaView with enforced secure connection (--connect-id)
/* #undef PARAVIEW_ALWAYS_SECURE_CONNECTION */

#define PARAVIEW_VERSION_MAJOR 3
#define PARAVIEW_VERSION_MINOR 8
#define PARAVIEW_VERSION_PATCH 0
#define PARAVIEW_VERSION_RC 
#define PARAVIEW_VERSION "3.8"
#define PARAVIEW_VERSION_FULL "3.8.0"

// Some runtime informations to be displayed in About box:
#define OPENGL_gl_LIBRARY   "/usr/local/lib/libGL.so"
#define OPENGL_INCLUDE_DIR  "/usr/local/include"
#define CMAKE_BUILD_TYPE    ""

#define CMAKE_CXX_COMPILER_ID "GNU"


// defined when SSEND must be used for communication by default.
/* #undef PARAVIEW_USE_MPI_SSEND */

// ParaView data root (useful for testing).
#define PARAVIEW_DATA_ROOT "PARAVIEW_DATA_ROOT-NOTFOUND"

// Should chroma-subsampling be used by default?
/* #undef PARAVIEW_OGGTHEORA_USE_SUBSAMPLING */

#define BUILD_SHARED_LIBS

#endif

==> paraview-3.8.1.tbz: include/paraview-3.8/vtkPVConfig.h <==
/*=========================================================================

  Program:   ParaView
  Module:    vtkPVConfig.h.in

  Copyright (c) Kitware, Inc.
  All rights reserved.
  See Copyright.txt or http://www.paraview.org/HTML/Copyright.html for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/

#ifndef __vtkPVConfig_h
#define __vtkPVConfig_h

#define PARAVIEW_LINK_XDMF
/* #undef PARAVIEW_USE_ICE_T */
#define PARAVIEW_USE_SYSTEM_HDF5
/* #undef PARAVIEW_USE_SILO */
/* #undef XDMF_SYSTEM_HDF5 */
/* #undef PARAVIEW_BUILD_DEVELOPMENT */
/* #undef PARAVIEW_BLT_LIBRARY */
/* #undef PARAVIEW_ENABLE_PYTHON */
/* #undef PARAVIEW_MINIMAL_BUILD */
#define PARAVIEW_BUILD_ARCHITECTURE "64"

// Indicates the Qt support is enabled in VTK.
#define VTK_USE_QVTK

// Build ParaView with Floating Point Exceptions turned on
/* #undef PARAVIEW_ENABLE_FPE */
//Build ParaView with enforced secure connection (--connect-id)
/* #undef PARAVIEW_ALWAYS_SECURE_CONNECTION */

#define PARAVIEW_VERSION_MAJOR 3
#define PARAVIEW_VERSION_MINOR 8
#define PARAVIEW_VERSION_PATCH 1
#define PARAVIEW_VERSION_RC 
#define PARAVIEW_VERSION "3.8"
#define PARAVIEW_VERSION_FULL "3.8.1"

// Some runtime informations to be displayed in About box:
#define OPENGL_gl_LIBRARY   "/usr/local/lib/libGL.so"
#define OPENGL_INCLUDE_DIR  "/usr/local/include"
#define CMAKE_BUILD_TYPE    ""

#define CMAKE_CXX_COMPILER_ID "GNU"


// defined when SSEND must be used for communication by default.
/* #undef PARAVIEW_USE_MPI */

// defined when SSEND must be used for communication by default.
/* #undef PARAVIEW_USE_MPI_SSEND */

// ParaView data root (useful for testing).
#define PARAVIEW_DATA_ROOT "PARAVIEW_DATA_ROOT-NOTFOUND"

// Should chroma-subsampling be used by default?
/* #undef PARAVIEW_OGGTHEORA_USE_SUBSAMPLING */

#define BUILD_SHARED_LIBS

#endif
